@@ -45,6 +45,7 @@ from socket import gethostbyname
 import tarfile
 from calculate.desktop.desktop import Desktop
 from calculate.client.rsync import ProfileSyncer, ProfileSyncerError
+from calculate.lib.utils.common import get_fastlogin_domain_path
 
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 
@@ -1434,3 +1435,17 @@ class Client(commandServer, encrypt, Desktop):
                 os.chmod(changeDir, 0700)
         self.endTask()
         return True
+
+    def update_fastlogin_domain_path(self):
+        fn = '/var/lib/calculate/calculate-desktop/fastlogin-domain'
+        try:
+            with writeFile(fn) as f:
+                f.write("{}\n".format(
+                    "\n".join(get_fastlogin_domain_path(self.clVars))))
+        except Exception:
+            if os.path.exists(fn):
+                try:
+                    os.unlink(fn)
+                except Exception:
+                    pass
+        return True
