@@ -44,7 +44,7 @@ class ClClientSyncLoginAction(Action):
 
     old_sync = [
         # подключить удаленные ресурсы пользователя
-        {'name': 'domain_sync:mount_resources',
+        {'name': 'oldsync:mount_resources',
          'message': __("Mounting user resources"),
          'method': 'Client.mountUserDomainRes(ur_login,'
                    'desktop.ur_password,'
@@ -170,7 +170,7 @@ class ClClientSyncLoginAction(Action):
 
     new_sync = [
         # подключить удаленные ресурсы пользователя
-        {'name': 'domain_sync2:mount_resources2',
+        {'name': 'newsync:mount_resources2',
          'message': __("Mounting user resources"),
          'method': 'Client.mountUserDomainRes(ur_login,'
                    'desktop.ur_password,'
@@ -279,20 +279,23 @@ class ClClientSyncLoginAction(Action):
                                       eq=dv.Get('ur_login'), limit=1) > 1) and
                                   dv.Get('cl_client_sync') == 'on')
          },
-        {'name': 'domain_user:newsync',
+        {'name': 'domain_user:check_sync',
          'method': 'Client.checkSync(cl_remote_host)',
          'essential': False,
-         'condition': lambda Get: Get('cl_client_sync') == 'on'
          },
-        {'name': 'domain_user:domain_sync',
+        {'name': 'domain_user:oldsync',
+         'depend': AllTasks.failed_one_of('check_sync')
+         },
+        {'name': 'domain_user:newsync',
+         'depend': AllTasks.success_one_of('check_sync')
+         },
+        {'name': 'oldsync:domain_sync',
          'method': 'Client.setSyncStatus(ur_home_path,ur_uid,ur_gid,"process")',
          'condition': lambda Get: Get('cl_client_sync') == 'on',
-         'depend': AllTasks.failed_one_of('newsync')
          },
-        {'name': 'domain_user:domain_sync2',
+        {'name': 'newsync:domain_sync2',
          'method': 'Client.setSyncStatus(ur_home_path,ur_uid,ur_gid,"process")',
          'condition': lambda Get: Get('cl_client_sync') == 'on',
-         'depend': AllTasks.success_one_of('newsync')
          }, ] + old_sync + new_sync + [
         # распаковать ссылки
         {'name': 'unpack_links',
